@@ -1,30 +1,19 @@
-"RM" <-
+`RM` <-
 function(X,W)
 {
 #...X: 0/1 person*item matrix
 
-#-----------sourcing required files-----------------
-#library("gtools")
-#source("C:/erm/additional/datcheck.r")
-#source("C:/erm/additional/datprep.r")
-#source("C:/erm/additional/cmlprep.r")
-#source("C:/erm/additional/cml.r")
-#source("C:/erm/additional/lr.r")
-#source("C:/erm/additional/likLR.r")
-
-#----------------end sourcing-----------------------
-
 #-------------------main programm-------------------
-Groups <- 1
+groups <- 1
 mpoints <- 1
 model <- "RM"
 if (missing(W)) W <- NA
+else W <- as.matrix(W)
 
 XWcheck <- datcheck(X,W)                              #inital check of X and W
 X <- XWcheck$X
 
-lres <- likLR(X,W,mpoints,Groups,model)
-likall123 <- lres$likall                              #values for subgroups for plot.eRm
+lres <- likLR(X,W,mpoints,groups,model)
 likall <- lres$likall[[1]]                            #full groups for parameter estimation
 LR <- lres$LR
                                 
@@ -33,10 +22,13 @@ iter <- likall[[1]]$iterations                         #number of iterations
 etapar <- likall[[1]]$estimate                         #eta estimates
 se <- sqrt(diag(solve(likall[[1]]$hessian)))           #standard errors
 betapar <- as.vector(lres$W%*% etapar)                 #beta estimates
-
-result <- list(loglik=loglik,iter=iter,etapar=etapar,se_eta=se,betapar=betapar,
-               LR=lres$LR,likall=likall,W=lres$W,likall123=likall123,G=lres$G,
-               mpoints=mpoints,ngroups=max(Groups))
+ 
+if (length(LR)>1) {
+  etaparG1 <- lres$likall[[2]][[1]]$estimate             #parameter vector group1 in LR-test (needed for plot method)
+  etaparG2 <- lres$likall[[3]][[1]]$estimate             #parameter vector group2 
+}
+result <- list(model=model,loglik=loglik,df=dim(lres$W)[2],iter=iter,etapar=etapar,se_eta=se,hessian=likall[[1]]$hessian,betapar=betapar,
+               LR=lres$LR,W=lres$W,etaparG1=etaparG1,etaparG2=etaparG2)
 class(result) <- c("Rm","eRm")                         #classes: simple RM and extended RM
 result
 }
